SaveError

Enum SaveError 

#[non_exhaustive]
pub enum SaveError { ConfigSerializationError { cause: Box<dyn Error + Send>, }, ModelSerializationError { model: Path, type_name: &'static str, cause: Box<dyn Error + Send>, }, EventSerializationError { event_id: usize, cause: Box<dyn Error + Send>, }, QuerySerializationError { query_id: usize, cause: Box<dyn Error + Send>, }, SchedulerQueueSerializationError { cause: Box<dyn Error + Send>, }, SimulationStateSerializationError { cause: Box<dyn Error + Send>, }, EventNotFound { event_id: usize, }, QueryNotFound { query_id: usize, }, ArgumentTypeMismatch { type_name: &'static str, }, ArgumentSerializationError { type_name: &'static str, cause: Box<dyn Error + Send>, }, }
An error returned upon failure during simulation state store procedure.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ConfigSerializationError

Serialization of the simulation’s config has failed.

Fields

cause: Box<dyn Error + Send>

Underlying serialization error.



ModelSerializationError

Failed attempt to binary encode model’s state.

Fields

model: Path

Path to the model.

type_name: &'static str

Type name of the model.

cause: Box<dyn Error + Send>

Underlying serialization error.



EventSerializationError

Failed attempt to serialize an event.

Fields

event_id: usize

Event’s sourceId.

cause: Box<dyn Error + Send>

Underlying serialization error.



QuerySerializationError

Failed attempt to serialize an event.

Fields

query_id: usize

Query’s sourceId.

cause: Box<dyn Error + Send>

Underlying serialization error.



SchedulerQueueSerializationError

Failed attempt to serialize the scheduler queue.

Fields

cause: Box<dyn Error + Send>

Underlying serialization error.



SimulationStateSerializationError

Failed attempt to serialize the complete simulation state.

Fields

cause: Box<dyn Error + Send>

Underlying serialization error.



EventNotFound

Failed attempt to save an event with an unknown id.

Fields

event_id: usize

Event’s sourceId.



QueryNotFound

Failed attempt to save a query with an unknown id.

Fields

query_id: usize

Query’s sourceId.



ArgumentTypeMismatch

Argument data downcasting to a concrete type has failed.

Fields

type_name: &'static str

Expected type name.



ArgumentSerializationError

Failed attempt to serialize an event argument.

Fields

type_name: &'static str

Expected type name.

cause: Box<dyn Error + Send>

Underlying serialization error.