#[non_exhaustive]pub enum SaveError {
ConfigSerializationError {
cause: Box<dyn Error + Send>,
},
ModelSerializationError {
model: Path,
type_name: &'static str,
cause: Box<dyn Error + Send>,
},
EventSerializationError {
event_id: usize,
cause: Box<dyn Error + Send>,
},
QuerySerializationError {
query_id: usize,
cause: Box<dyn Error + Send>,
},
SchedulerQueueSerializationError {
cause: Box<dyn Error + Send>,
},
SimulationStateSerializationError {
cause: Box<dyn Error + Send>,
},
EventNotFound {
event_id: usize,
},
QueryNotFound {
query_id: usize,
},
ArgumentTypeMismatch {
type_name: &'static str,
},
ArgumentSerializationError {
type_name: &'static str,
cause: Box<dyn Error + Send>,
},
}Expand description
An error returned upon failure during simulation state store procedure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ConfigSerializationError
Serialization of the simulation’s config has failed.
ModelSerializationError
Failed attempt to binary encode model’s state.
Fields
EventSerializationError
Failed attempt to serialize an event.
Fields
QuerySerializationError
Failed attempt to serialize an event.
Fields
SchedulerQueueSerializationError
Failed attempt to serialize the scheduler queue.
SimulationStateSerializationError
Failed attempt to serialize the complete simulation state.
EventNotFound
Failed attempt to save an event with an unknown id.
QueryNotFound
Failed attempt to save a query with an unknown id.
ArgumentTypeMismatch
Argument data downcasting to a concrete type has failed.
ArgumentSerializationError
Failed attempt to serialize an event argument.